@@ -318,7 +318,7 @@ class CurEmpPosition(models.Model):
 
 class CurEmpDivision(models.Model):
 	employee = models.OneToOneField(Employee, on_delete=models.CASCADE, null=True, related_name="curempdivision")
-	de = models.ForeignKey(DE, on_delete=models.CASCADE, null=True, blank=True, related_name="curempdivision")
+	de = models.ForeignKey(DE, on_delete=models.CASCADE, null=True, blank=True, verbose_name="Presidente/Vice",  related_name="curempdivision")
 	unit = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name="curempdivision")
 	department = models.ForeignKey(Department, on_delete=models.CASCADE, null=True, blank=True, related_name="curempdivision")
 	def __str__(self):
