@@ -148,53 +148,58 @@ def EmployeeLeaveDetail(request, hashid):
 	contract = Contract.objects.filter(employee=employee, is_active=True).last()
 	try:
 		today = datetime.today().date()
-		period  = get_object_or_404(LeavePeriod, employee=employee, is_active=True)
-		leave = Leave.objects.filter(employee=employee, leave_period=period).order_by('-start_date')
-		
-		min_month = f'{period.start_year.year}-{period.start_month.code}-{period.start_date.day}'
-		max_month = f'{today.year}-{today.month}-{period.start_date.day}'
-		months = pd.date_range(min_month, max_month, freq='M')
-		check_last_period = LeavePeriod.objects.filter(employee=employee,pk__lt=period.pk).last()
-		all_period = LeavePeriod.objects.filter(employee=employee)
-		last_count_period = LeaveCount.objects.filter(employee=employee, period=check_last_period, leave_type_id=1).last()
-		lt = LeaveType.objects.all()
-		data = []
-		data2 = []
-		allmonth = check_period_range(period)
-		for obj in allmonth:
-			al = LeaveCount.objects.filter(employee=employee, period=period,  month__code=obj.month, year__year=obj.year, leave_type_id=1).last()
-			sl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=2).last()
-			spl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=3).last()
-			mtl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=4).last()
-			ptl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=5).last()
-			cl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=6).last()
-			lmonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=obj.month, start_date__year=obj.year,leave_type_id=1).exists()
+		period = LeavePeriod.objects.filter(employee=employee, is_active=True).last()
+		if period:
+			period  = get_object_or_404(LeavePeriod, employee=employee, is_active=True)
+			leave = Leave.objects.filter(employee=employee, leave_period=period).order_by('-start_date')
+			
+			min_month = f'{period.start_year.year}-{period.start_month.code}-{period.start_date.day}'
+			max_month = f'{today.year}-{today.month}-{period.start_date.day}'
+			months = pd.date_range(min_month, max_month, freq='M')
+			check_last_period = LeavePeriod.objects.filter(employee=employee,pk__lt=period.pk).last()
+			all_period = LeavePeriod.objects.filter(employee=employee)
+			last_count_period = LeaveCount.objects.filter(employee=employee, period=check_last_period, leave_type_id=1).last()
+			lt = LeaveType.objects.all()
+			data = []
+			data2 = []
+			allmonth = check_period_range(period)
+			for obj in allmonth:
+				al = LeaveCount.objects.filter(employee=employee, period=period,  month__code=obj.month, year__year=obj.year, leave_type_id=1).last()
+				sl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=2).last()
+				spl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=3).last()
+				mtl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=4).last()
+				ptl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=5).last()
+				cl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=6).last()
+				lmonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=obj.month, start_date__year=obj.year,leave_type_id=1).exists()
 
-			data2.append([obj, al,sl, spl, mtl, ptl, cl, lmonth])
-		objects = []
-		alleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1).last()
-		alleavelast = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__lt=today).last()
-		alleavenext = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__gt=today).first()
-		sickleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=2).all().order_by('pk')
-		spleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=3).all().order_by('pk')
-		mtleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=4).all().order_by('pk')
-		ptleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=5).all().order_by('pk')
-		chleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=6).all().order_by('pk')
-		leavecheck = LeaveCount.objects.filter(employee=employee, period=period, period__employee=employee ).exists()
-		leavemonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=today.month, start_date__year=today.year,leave_type_id=1).exists()
-		objects.append([alleave, spleave,sickleave, mtleave, ptleave,chleave, data, leavemonth, alleavelast,alleavenext])
+				data2.append([obj, al,sl, spl, mtl, ptl, cl, lmonth])
+			objects = []
+			alleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1).last()
+			alleavelast = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__lt=today).last()
+			alleavenext = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__gt=today).first()
+			sickleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=2).all().order_by('pk')
+			spleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=3).all().order_by('pk')
+			mtleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=4).all().order_by('pk')
+			ptleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=5).all().order_by('pk')
+			chleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=6).all().order_by('pk')
+			leavecheck = LeaveCount.objects.filter(employee=employee, period=period, period__employee=employee ).exists()
+			leavemonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=today.month, start_date__year=today.year,leave_type_id=1).exists()
+			objects.append([alleave, spleave,sickleave, mtleave, ptleave,chleave, data, leavemonth, alleavelast,alleavenext])
 
-		check_date = check_period_date(period.start_date)
-		check_last_month_per = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1,  month__code=1, year__year=2023).exists()
+			check_date = check_period_date(period.start_date)
+			check_last_month_per = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1,  month__code=1, year__year=2023).exists()
 
-		context = {
-			'group': group, 'employee':employee, 'alleave':alleave, 'period':period, 'leave':leave, 'last_count_period':last_count_period, 'today':check_date,
-			'title': 'Balansu Licensa no Historia', 'legend': 'Balansu Licensa no Historia', 'objects': objects, 'leavecheck':leavecheck, 'all_period':all_period, 'contract':contract, \
-			'check_last_month_per':check_last_month_per, 'today':today,'allmonth':allmonth, 'data':data2, 'today':today, 'page':'leave'
-		}
-		return render(request, 'employee/emp_detail.html', context)				
+			context = {
+				'group': group, 'employee':employee, 'alleave':alleave, 'period':period, 'leave':leave, 'last_count_period':last_count_period, 'today':check_date,
+				'title': 'Balansu Licensa no Historia', 'legend': 'Balansu Licensa no Historia', 'objects': objects, 'leavecheck':leavecheck, 'all_period':all_period, 'contract':contract, \
+				'check_last_month_per':check_last_month_per, 'today':today,'allmonth':allmonth, 'data':data2, 'today':today, 'page':'leave'
+			}
+			return render(request, 'employee/emp_detail.html', context)	
+		else:
+			messages.error(request, 'Periode Licensa Seidauk Iha!!')
+			return redirect('emp-detail', employee.hashed)
 	except:
-		if contract.start_date:
+		if contract:
 			context = {
 				'legend': 'Balansu Licensa no Historia', 'title': 'Balansu Licensa no Historia', 'employee':employee, 'contract': contract, 'page':'leave'
 			}
